@@ -119,6 +119,9 @@ struct OBSStudioAPI : obs_frontend_callbacks {
 			OBSSource tr = main->ui->transitions->itemData(i)
 					       .value<OBSSource>();
 
+			if (!tr)
+				continue;
+
 			obs_source_addref(tr);
 			da_push_back(sources->sources, &tr);
 		}
@@ -151,6 +154,17 @@ struct OBSStudioAPI : obs_frontend_callbacks {
 					  "setValue", Q_ARG(int, duration));
 	}
 
+	void obs_frontend_release_tbar(void) override
+	{
+		QMetaObject::invokeMethod(main, "TBarReleased");
+	}
+
+	void obs_frontend_set_tbar_position(int position) override
+	{
+		QMetaObject::invokeMethod(main, "TBarChanged",
+					  Q_ARG(int, position));
+	}
+
 	void obs_frontend_get_scene_collections(
 		std::vector<std::string> &strings) override
 	{
@@ -523,6 +537,17 @@ struct OBSStudioAPI : obs_frontend_callbacks {
 		}
 	}
 
+	void obs_frontend_take_screenshot(void) override
+	{
+		QMetaObject::invokeMethod(main, "Screenshot");
+	}
+
+	void obs_frontend_take_source_screenshot(obs_source_t *source) override
+	{
+		QMetaObject::invokeMethod(main, "Screenshot",
+					  Q_ARG(OBSSource, OBSSource(source)));
+	}
+
 	void on_load(obs_data_t *settings) override
 	{
 		for (size_t i = saveCallbacks.size(); i > 0; i--) {
