@@ -573,6 +573,7 @@ public slots:
 
 	void ReplayBufferStart();
 	void ReplayBufferSave();
+	void ReplayBufferSaved();
 	void ReplayBufferStopping();
 	void ReplayBufferStop(int code);
 
@@ -839,6 +840,8 @@ public:
 	QIcon GetGroupIcon() const;
 	QIcon GetSceneIcon() const;
 
+	OBSWeakSource copyFilter = nullptr;
+
 protected:
 	virtual void closeEvent(QCloseEvent *event) override;
 	virtual void changeEvent(QEvent *event) override;
@@ -1020,7 +1023,8 @@ public slots:
 	bool ReplayBufferActive();
 
 	void ClearContextBar();
-	void UpdateContextBar();
+	void UpdateContextBar(bool force = false);
+	void UpdateContextBarDeferred(bool force = false);
 
 public:
 	explicit OBSBasic(QWidget *parent = 0);
