@@ -138,7 +138,7 @@ void ExtraBrowsersModel::AddDeleteButton(int idx)
 	QPushButton *del = new DelButton(index);
 	del->setProperty("themeID", "trashIcon");
 	del->setObjectName("extraPanelDelete");
-	del->setFixedSize(QSize(20, 20));
+	del->setMinimumSize(QSize(20, 20));
 	connect(del, &QPushButton::clicked, this,
 		&ExtraBrowsersModel::DeleteItem);
 
@@ -522,7 +522,7 @@ void OBSBasic::AddExtraBrowserDock(const QString &title, const QString &url,
 	BrowserDock *dock = new BrowserDock();
 	dock->setObjectName(title + OBJ_NAME_SUFFIX);
 	dock->resize(460, 600);
-	dock->setMinimumSize(150, 150);
+	dock->setMinimumSize(80, 80);
 	dock->setWindowTitle(title);
 	dock->setAllowedAreas(Qt::AllDockWidgetAreas);
 
