@@ -16,14 +16,23 @@
 ******************************************************************************/
 
 #include <QClipboard>
+#include <QUrl>
+#include <QUrlQuery>
+#include <QDesktopServices>
 #include "window-log-reply.hpp"
 #include "obs-app.hpp"
 
-OBSLogReply::OBSLogReply(QWidget *parent, const QString &url)
+OBSLogReply::OBSLogReply(QWidget *parent, const QString &url, const bool crash)
 	: QDialog(parent), ui(new Ui::OBSLogReply)
 {
+	setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
 	ui->setupUi(this);
 	ui->urlEdit->setText(url);
+	if (crash) {
+		ui->analyzeURL->hide();
+		ui->description->setText(
+			Str("LogReturnDialog.Description.Crash"));
+	}
 
 	installEventFilter(CreateShortcutFilter());
 }
@@ -33,3 +42,13 @@ void OBSLogReply::on_copyURL_clicked()
 	QClipboard *clipboard = QApplication::clipboard();
 	clipboard->setText(ui->urlEdit->text());
 }
+
+void OBSLogReply::on_analyzeURL_clicked()
+{
+	QUrlQuery param;
+	param.addQueryItem("log_url",
+			   QUrl::toPercentEncoding(ui->urlEdit->text()));
+	QUrl url("https://obsproject.com/tools/analyzer", QUrl::TolerantMode);
+	url.setQuery(param);
+	QDesktopServices::openUrl(url);
+}
