@@ -1264,7 +1264,6 @@ void device_set_viewport(gs_device_t *device, int x, int y, int width,
 			 int height)
 {
 	uint32_t base_height = 0;
-	int gl_y = 0;
 
 	/* GL uses bottom-up coordinates for viewports.  We want top-down */
 	if (device->cur_render_target) {
@@ -1274,7 +1273,8 @@ void device_set_viewport(gs_device_t *device, int x, int y, int width,
 		gl_getclientsize(device->cur_swap, &dw, &base_height);
 	}
 
-	if (base_height)
+	GLint gl_y = y;
+	if (base_height && !device->cur_fbo)
 		gl_y = base_height - y - height;
 
 	glViewport(x, gl_y, width, height);
