@@ -1,4 +1,4 @@
-#include "../../obs-internal.h"
+#include <obs-internal.h>
 
 void obs_enum_audio_monitoring_devices(obs_enum_audio_device_cb cb, void *data)
 {
