@@ -16,7 +16,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <math.h>
-#include <xmmintrin.h>
+
+#include "util/sse-intrin.h"
 
 #include "util/threading.h"
 #include "util/bmem.h"
