@@ -539,7 +539,7 @@ static const uint8_t *set_gpu_converted_plane(uint32_t width, uint32_t height,
 					      const uint8_t *in, uint8_t *out)
 {
 	if ((width == linesize_input) && (width == linesize_output)) {
-		size_t total = width * height;
+		size_t total = (size_t)width * (size_t)height;
 		memcpy(out, in, total);
 		in += total;
 	} else {
@@ -672,10 +672,12 @@ static inline void copy_rgbx_frame(struct video_frame *output,
 
 	/* if the line sizes match, do a single copy */
 	if (input->linesize[0] == output->linesize[0]) {
-		memcpy(out_ptr, in_ptr, input->linesize[0] * info->height);
+		memcpy(out_ptr, in_ptr,
+		       (size_t)input->linesize[0] * (size_t)info->height);
 	} else {
+		const size_t copy_size = (size_t)info->width * 4;
 		for (size_t y = 0; y < info->height; y++) {
-			memcpy(out_ptr, in_ptr, info->width * 4);
+			memcpy(out_ptr, in_ptr, copy_size);
 			in_ptr += input->linesize[0];
 			out_ptr += output->linesize[0];
 		}
@@ -835,24 +837,188 @@ static void execute_graphics_tasks(void)
 	}
 }
 
+#ifdef _WIN32
+
+struct winrt_exports {
+	void (*winrt_initialize)();
+	void (*winrt_uninitialize)();
+	struct winrt_disaptcher *(*winrt_dispatcher_init)();
+	void (*winrt_dispatcher_free)(struct winrt_disaptcher *dispatcher);
+	void (*winrt_capture_thread_start)();
+	void (*winrt_capture_thread_stop)();
+};
+
+#define WINRT_IMPORT(func)                                        \
+	do {                                                      \
+		exports->func = os_dlsym(module, #func);          \
+		if (!exports->func) {                             \
+			success = false;                          \
+			blog(LOG_ERROR,                           \
+			     "Could not load function '%s' from " \
+			     "module '%s'",                       \
+			     #func, module_name);                 \
+		}                                                 \
+	} while (false)
+
+static bool load_winrt_imports(struct winrt_exports *exports, void *module,
+			       const char *module_name)
+{
+	bool success = true;
+
+	WINRT_IMPORT(winrt_initialize);
+	WINRT_IMPORT(winrt_uninitialize);
+	WINRT_IMPORT(winrt_dispatcher_init);
+	WINRT_IMPORT(winrt_dispatcher_free);
+	WINRT_IMPORT(winrt_capture_thread_start);
+	WINRT_IMPORT(winrt_capture_thread_stop);
+
+	return success;
+}
+
+struct winrt_state {
+	bool loaded;
+	void *winrt_module;
+	struct winrt_exports exports;
+	struct winrt_disaptcher *dispatcher;
+};
+
+static void init_winrt_state(struct winrt_state *winrt)
+{
+	static const char *const module_name = "libobs-winrt";
+
+	winrt->winrt_module = os_dlopen(module_name);
+	winrt->loaded = winrt->winrt_module &&
+			load_winrt_imports(&winrt->exports, winrt->winrt_module,
+					   module_name);
+	winrt->dispatcher = NULL;
+	if (winrt->loaded) {
+		winrt->exports.winrt_initialize();
+		winrt->dispatcher = winrt->exports.winrt_dispatcher_init();
+
+		gs_enter_context(obs->video.graphics);
+		winrt->exports.winrt_capture_thread_start();
+		gs_leave_context();
+	}
+}
+
+static void uninit_winrt_state(struct winrt_state *winrt)
+{
+	if (winrt->winrt_module) {
+		if (winrt->loaded) {
+			winrt->exports.winrt_capture_thread_stop();
+			if (winrt->dispatcher)
+				winrt->exports.winrt_dispatcher_free(
+					winrt->dispatcher);
+			winrt->exports.winrt_uninitialize();
+		}
+
+		os_dlclose(winrt->winrt_module);
+	}
+}
+
+#endif // #ifdef _WIN32
+
 static const char *tick_sources_name = "tick_sources";
 static const char *render_displays_name = "render_displays";
 static const char *output_frame_name = "output_frame";
+bool obs_graphics_thread_loop(struct obs_graphics_context *context)
+{
+	/* defer loop break to clean up sources */
+	const bool stop_requested = video_output_stopped(obs->video.video);
+
+	uint64_t frame_start = os_gettime_ns();
+	uint64_t frame_time_ns;
+	bool raw_active = obs->video.raw_active > 0;
+#ifdef _WIN32
+	const bool gpu_active = obs->video.gpu_encoder_active > 0;
+	const bool active = raw_active || gpu_active;
+#else
+	const bool gpu_active = 0;
+	const bool active = raw_active;
+#endif
+
+	if (!context->was_active && active)
+		clear_base_frame_data();
+	if (!context->raw_was_active && raw_active)
+		clear_raw_frame_data();
+#ifdef _WIN32
+	if (!context->gpu_was_active && gpu_active)
+		clear_gpu_frame_data();
+
+	context->gpu_was_active = gpu_active;
+#endif
+	context->raw_was_active = raw_active;
+	context->was_active = active;
+
+	profile_start(context->video_thread_name);
+
+	gs_enter_context(obs->video.graphics);
+	gs_begin_frame();
+	gs_leave_context();
+
+	profile_start(tick_sources_name);
+	context->last_time =
+		tick_sources(obs->video.video_time, context->last_time);
+	profile_end(tick_sources_name);
+
+	execute_graphics_tasks();
+
+#ifdef _WIN32
+	MSG msg;
+	while (PeekMessage(&msg, NULL, 0, 0, PM_REMOVE)) {
+		TranslateMessage(&msg);
+		DispatchMessage(&msg);
+	}
+#endif
+
+	profile_start(output_frame_name);
+	output_frame(raw_active, gpu_active);
+	profile_end(output_frame_name);
+
+	profile_start(render_displays_name);
+	render_displays();
+	profile_end(render_displays_name);
+
+	frame_time_ns = os_gettime_ns() - frame_start;
+
+	profile_end(context->video_thread_name);
+
+	profile_reenable_thread();
+
+	video_sleep(&obs->video, raw_active, gpu_active, &obs->video.video_time,
+		    context->interval);
+
+	context->frame_time_total_ns += frame_time_ns;
+	context->fps_total_ns += (obs->video.video_time - context->last_time);
+	context->fps_total_frames++;
+
+	if (context->fps_total_ns >= 1000000000ULL) {
+		obs->video.video_fps =
+			(double)context->fps_total_frames /
+			((double)context->fps_total_ns / 1000000000.0);
+		obs->video.video_avg_frame_time_ns =
+			context->frame_time_total_ns /
+			(uint64_t)context->fps_total_frames;
+
+		context->frame_time_total_ns = 0;
+		context->fps_total_ns = 0;
+		context->fps_total_frames = 0;
+	}
+
+	return !stop_requested;
+}
+
 void *obs_graphics_thread(void *param)
 {
-	uint64_t last_time = 0;
-	uint64_t interval = video_output_get_frame_time(obs->video.video);
-	uint64_t frame_time_total_ns = 0;
-	uint64_t fps_total_ns = 0;
-	uint32_t fps_total_frames = 0;
 #ifdef _WIN32
-	bool gpu_was_active = false;
-#endif
-	bool raw_was_active = false;
-	bool was_active = false;
+	struct winrt_state winrt;
+	init_winrt_state(&winrt);
+#endif // #ifdef _WIN32
 
 	is_graphics_thread = true;
 
+	const uint64_t interval = video_output_get_frame_time(obs->video.video);
+
 	obs->video.video_time = os_gettime_ns();
 	obs->video.video_frame_interval_ns = interval;
 
@@ -865,93 +1031,30 @@ void *obs_graphics_thread(void *param)
 
 	srand((unsigned int)time(NULL));
 
-	for (;;) {
-		/* defer loop break to clean up sources */
-		const bool stop_requested =
-			video_output_stopped(obs->video.video);
-
-		uint64_t frame_start = os_gettime_ns();
-		uint64_t frame_time_ns;
-		bool raw_active = obs->video.raw_active > 0;
+	struct obs_graphics_context context;
+	context.interval = video_output_get_frame_time(obs->video.video);
+	context.frame_time_total_ns = 0;
+	context.fps_total_ns = 0;
+	context.fps_total_frames = 0;
+	context.last_time = 0;
 #ifdef _WIN32
-		const bool gpu_active = obs->video.gpu_encoder_active > 0;
-		const bool active = raw_active || gpu_active;
+	context.gpu_was_active = false;
+#endif
+	context.raw_was_active = false;
+	context.was_active = false;
+	context.video_thread_name = video_thread_name;
+
+#ifdef __APPLE__
+	while (obs_graphics_thread_loop_autorelease(&context))
 #else
-		const bool gpu_active = 0;
-		const bool active = raw_active;
+	while (obs_graphics_thread_loop(&context))
 #endif
-
-		if (!was_active && active)
-			clear_base_frame_data();
-		if (!raw_was_active && raw_active)
-			clear_raw_frame_data();
-#ifdef _WIN32
-		if (!gpu_was_active && gpu_active)
-			clear_gpu_frame_data();
-
-		gpu_was_active = gpu_active;
-#endif
-		raw_was_active = raw_active;
-		was_active = active;
-
-		profile_start(video_thread_name);
-
-		gs_enter_context(obs->video.graphics);
-		gs_begin_frame();
-		gs_leave_context();
-
-		profile_start(tick_sources_name);
-		last_time = tick_sources(obs->video.video_time, last_time);
-		profile_end(tick_sources_name);
-
-		execute_graphics_tasks();
+		;
 
 #ifdef _WIN32
-		MSG msg;
-		while (PeekMessage(&msg, NULL, 0, 0, PM_REMOVE)) {
-			TranslateMessage(&msg);
-			DispatchMessage(&msg);
-		}
+	uninit_winrt_state(&winrt);
 #endif
 
-		profile_start(output_frame_name);
-		output_frame(raw_active, gpu_active);
-		profile_end(output_frame_name);
-
-		profile_start(render_displays_name);
-		render_displays();
-		profile_end(render_displays_name);
-
-		frame_time_ns = os_gettime_ns() - frame_start;
-
-		profile_end(video_thread_name);
-
-		profile_reenable_thread();
-
-		video_sleep(&obs->video, raw_active, gpu_active,
-			    &obs->video.video_time, interval);
-
-		frame_time_total_ns += frame_time_ns;
-		fps_total_ns += (obs->video.video_time - last_time);
-		fps_total_frames++;
-
-		if (fps_total_ns >= 1000000000ULL) {
-			obs->video.video_fps =
-				(double)fps_total_frames /
-				((double)fps_total_ns / 1000000000.0);
-			obs->video.video_avg_frame_time_ns =
-				frame_time_total_ns /
-				(uint64_t)fps_total_frames;
-
-			frame_time_total_ns = 0;
-			fps_total_ns = 0;
-			fps_total_frames = 0;
-		}
-
-		if (stop_requested)
-			break;
-	}
-
 	UNUSED_PARAMETER(param);
 	return NULL;
 }
