@@ -49,25 +49,26 @@ EXPORT size_t os_fread_utf8(FILE *file, char **pstr);
 /* functions purely for convenience */
 EXPORT char *os_quick_read_utf8_file(const char *path);
 EXPORT bool os_quick_write_utf8_file(const char *path, const char *str,
-		size_t len, bool marker);
+				     size_t len, bool marker);
 EXPORT bool os_quick_write_utf8_file_safe(const char *path, const char *str,
-		size_t len, bool marker, const char *temp_ext,
-		const char *backup_ext);
+					  size_t len, bool marker,
+					  const char *temp_ext,
+					  const char *backup_ext);
 EXPORT char *os_quick_read_mbs_file(const char *path);
 EXPORT bool os_quick_write_mbs_file(const char *path, const char *str,
-		size_t len);
+				    size_t len);
 
 EXPORT int64_t os_get_file_size(const char *path);
 EXPORT int64_t os_get_free_space(const char *path);
 
 EXPORT size_t os_mbs_to_wcs(const char *str, size_t str_len, wchar_t *dst,
-		size_t dst_size);
+			    size_t dst_size);
 EXPORT size_t os_utf8_to_wcs(const char *str, size_t len, wchar_t *dst,
-		size_t dst_size);
+			     size_t dst_size);
 EXPORT size_t os_wcs_to_mbs(const wchar_t *str, size_t len, char *dst,
-		size_t dst_size);
+			    size_t dst_size);
 EXPORT size_t os_wcs_to_utf8(const wchar_t *str, size_t len, char *dst,
-		size_t dst_size);
+			     size_t dst_size);
 
 EXPORT size_t os_mbs_to_wcs_ptr(const char *str, size_t len, wchar_t **pstr);
 EXPORT size_t os_utf8_to_wcs_ptr(const char *str, size_t len, wchar_t **pstr);
@@ -88,12 +89,12 @@ struct os_cpu_usage_info;
 typedef struct os_cpu_usage_info os_cpu_usage_info_t;
 
 EXPORT os_cpu_usage_info_t *os_cpu_usage_info_start(void);
-EXPORT double              os_cpu_usage_info_query(os_cpu_usage_info_t *info);
-EXPORT void                os_cpu_usage_info_destroy(os_cpu_usage_info_t *info);
+EXPORT double os_cpu_usage_info_query(os_cpu_usage_info_t *info);
+EXPORT void os_cpu_usage_info_destroy(os_cpu_usage_info_t *info);
 
 typedef const void os_performance_token_t;
 EXPORT os_performance_token_t *os_request_high_performance(const char *reason);
-EXPORT void                   os_end_high_performance(os_performance_token_t *);
+EXPORT void os_end_high_performance(os_performance_token_t *);
 
 /**
  * Sleeps to a specific time (in nanoseconds).  Doesn't have to be super
@@ -138,7 +139,7 @@ struct os_globent {
 };
 
 struct os_glob_info {
-	size_t             gl_pathc;
+	size_t gl_pathc;
 	struct os_globent *gl_pathv;
 };
 
@@ -157,19 +158,19 @@ EXPORT int os_chdir(const char *path);
 
 EXPORT uint64_t os_get_free_disk_space(const char *dir);
 
-#define MKDIR_EXISTS   1
-#define MKDIR_SUCCESS  0
-#define MKDIR_ERROR   -1
+#define MKDIR_EXISTS 1
+#define MKDIR_SUCCESS 0
+#define MKDIR_ERROR -1
 
 EXPORT int os_mkdir(const char *path);
 EXPORT int os_mkdirs(const char *path);
 EXPORT int os_rename(const char *old_path, const char *new_path);
 EXPORT int os_copyfile(const char *file_in, const char *file_out);
 EXPORT int os_safe_replace(const char *target_path, const char *from_path,
-		const char *backup_path);
+			   const char *backup_path);
 
 EXPORT char *os_generate_formatted_filename(const char *extension, bool space,
-		const char *format);
+					    const char *format);
 
 struct os_inhibit_info;
 typedef struct os_inhibit_info os_inhibit_t;
@@ -202,6 +203,7 @@ EXPORT uint64_t os_get_proc_virtual_size(void);
 #endif
 #endif
 
+/* clang-format off */
 #ifdef __APPLE__
 # define ARCH_BITS 64
 #else
@@ -219,6 +221,7 @@ EXPORT uint64_t os_get_proc_virtual_size(void);
 #  endif
 # endif
 #endif
+/* clang-format on */
 
 #ifdef __cplusplus
 }
